==> ejc-probuilddiary-impl-3.0.0-20220919.091720-11-sources.jar: com/ejianc/business/probuilddiary/ledger/bean/LedgerQualityEntity.java <==
package com.ejianc.business.probuilddiary.ledger.bean;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;

import java.util.Date;

/**
 * 日志台账-工程质量检查、验收情况（质检员）
 *
 * @author baipengyan
 */
@TableName("ejc_probuilddiary_ledger_quality")
public class LedgerQualityEntity extends BaseEntity {
	private static final long serialVersionUID = 7765555135551014593L;

	@TableField(value = "person_id")
	private Long personId; // 个人日志id
	@TableField(value = "quality_id")
	private Long qualityId; // 工作类别id
	@TableField(value = "quality_name")
	private String qualityName; // 工作类别名称
	@TableField(value = "quality_code")
	private String qualityCode; // 工作类别编码
	@TableField(value = "quality_memo")
	private String qualityMemo; // 工作描述
	@TableField(value = "commit_user_id")
	private Long commitUserId; // 提交人id
	@TableField(value = "commit_user_code")
	private String commitUserCode; // 提交人账号
	@TableField(value = "commit_user_name")
	private String commitUserName; // 提交人名称
	@TableField(value = "commit_date")
	private Date commitDate; // 提交日期
	@TableField(value = "project_log_id")
	private Long projectLogId; // 项目日志id
	@TableField(value = "ledger_id")
	private Long ledgerId; // 日志台账id
	@TableField(value = "file_type")
	private String fileType; // 文件类型


	public Long getPersonId() {
		return personId;
	}

	public void setPersonId(Long personId) {
		this.personId = personId;
	}

	public Long getQualityId() {
		return qualityId;
	}

	public void setQualityId(Long qualityId) {
		this.qualityId = qualityId;
	}

	public String getQualityName() {
		return qualityName;
	}

	public void setQualityName(String qualityName) {
		this.qualityName = qualityName;
	}

	public String getQualityCode() {
		return qualityCode;
	}

	public void setQualityCode(String qualityCode) {
		this.qualityCode = qualityCode;
	}

	public String getQualityMemo() {
		return qualityMemo;
	}

	public void setQualityMemo(String qualityMemo) {
		this.qualityMemo = qualityMemo;
	}

	public Long getCommitUserId() {
		return commitUserId;
	}

	public void setCommitUserId(Long commitUserId) {
		this.commitUserId = commitUserId;
	}

	public String getCommitUserCode() {
		return commitUserCode;
	}

	public void setCommitUserCode(String commitUserCode) {
		this.commitUserCode = commitUserCode;
	}

	public String getCommitUserName() {
		return commitUserName;
	}

	public void setCommitUserName(String commitUserName) {
		this.commitUserName = commitUserName;
	}

	public Date getCommitDate() {
		return commitDate;
	}

	public void setCommitDate(Date commitDate) {
		this.commitDate = commitDate;
	}

	public Long getProjectLogId() {
		return projectLogId;
	}

	public void setProjectLogId(Long projectLogId) {
		this.projectLogId = projectLogId;
	}

	public Long getLedgerId() {
		return ledgerId;
	}

	public void setLedgerId(Long ledgerId) {
		this.ledgerId = ledgerId;
	}

	public String getFileType() {
		return fileType;
	}

	public void setFileType(String fileType) {
		this.fileType = fileType;
	}
}

==> ejc-probuilddiary-impl-3.0.0-20220919.110857-13-sources.jar: com/ejianc/business/probuilddiary/ledger/bean/LedgerQualityEntity.java <==
package com.ejianc.business.probuilddiary.ledger.bean;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;

import java.util.Date;

/**
 * 日志台账-工程质量检查、验收情况（质检员）
 *
 * @author baipengyan
 */
@TableName("ejc_probuilddiary_ledger_quality")
public class LedgerQualityEntity extends BaseEntity {
	private static final long serialVersionUID = 7765555135551014593L;

	@TableField(value = "person_id")
	private Long personId; // 个人日志id
	@TableField(value = "quality_id")
	private Long qualityId; // 工作类别id
	@TableField(value = "quality_name")
	private String qualityName; // 工作类别名称
	@TableField(value = "quality_code")
	private String qualityCode; // 工作类别编码
	@TableField(value = "quality_memo")
	private String qualityMemo; // 工作描述
	@TableField(value = "commit_user_id")
	private Long commitUserId; // 提交人id
	@TableField(value = "commit_user_code")
	private String commitUserCode; // 提交人账号
	@TableField(value = "commit_user_name")
	private String commitUserName; // 提交人名称
	@TableField(value = "commit_date")
	private Date commitDate; // 提交日期
	@TableField(value = "project_log_id")
	private Long projectLogId; // 项目日志id
	@TableField(value = "ledger_id")
	private Long ledgerId; // 日志台账id
	@TableField(value = "file_type")
	private String fileType; // 文件类型
	@TableField(value = "log_number")
	private String logNumber; // 日志项编码
	@TableField(value = "project_manager_flag")
	private Boolean projectManagerFlag; // 项目经理标识


	public Long getPersonId() {
		return personId;
	}

	public void setPersonId(Long personId) {
		this.personId = personId;
	}

	public Long getQualityId() {
		return qualityId;
	}

	public void setQualityId(Long qualityId) {
		this.qualityId = qualityId;
	}

	public String getQualityName() {
		return qualityName;
	}

	public void setQualityName(String qualityName) {
		this.qualityName = qualityName;
	}

	public String getQualityCode() {
		return qualityCode;
	}

	public void setQualityCode(String qualityCode) {
		this.qualityCode = qualityCode;
	}

	public String getQualityMemo() {
		return qualityMemo;
	}

	public void setQualityMemo(String qualityMemo) {
		this.qualityMemo = qualityMemo;
	}

	public Long getCommitUserId() {
		return commitUserId;
	}

	public void setCommitUserId(Long commitUserId) {
		this.commitUserId = commitUserId;
	}

	public String getCommitUserCode() {
		return commitUserCode;
	}

	public void setCommitUserCode(String commitUserCode) {
		this.commitUserCode = commitUserCode;
	}

	public String getCommitUserName() {
		return commitUserName;
	}

	public void setCommitUserName(String commitUserName) {
		this.commitUserName = commitUserName;
	}

	public Date getCommitDate() {
		return commitDate;
	}

	public void setCommitDate(Date commitDate) {
		this.commitDate = commitDate;
	}

	public Long getProjectLogId() {
		return projectLogId;
	}

	public void setProjectLogId(Long projectLogId) {
		this.projectLogId = projectLogId;
	}

	public Long getLedgerId() {
		return ledgerId;
	}

	public void setLedgerId(Long ledgerId) {
		this.ledgerId = ledgerId;
	}

	public String getFileType() {
		return fileType;
	}

	public void setFileType(String fileType) {
		this.fileType = fileType;
	}

	public String getLogNumber() {
		return logNumber;
	}

	public void setLogNumber(String logNumber) {
		this.logNumber = logNumber;
	}

	public Boolean getProjectManagerFlag() {
		return projectManagerFlag;
	}

	public void setProjectManagerFlag(Boolean projectManagerFlag) {
		this.projectManagerFlag = projectManagerFlag;
	}
}
